/* This program converts the analog input from the potentiometer
 * on the EduPad.
 * Channel 5 is configured as a single-ended input from PA05.
 * External reference A is used from PA03. Clock prescaler
 * is left at 0 (divided by 4) and Sampling time is set to
 * 5 clock cycles (20 us).
 * Software trigger is used. The bit 11-8 of the conversion
 * result areused to turn on/off the LEDs. 
 *
 * Connections between SAMD21 Xplained Pro and EduPad:
 *
 * Function     Pin name      Xplained pin   EduPad pin
 * AIN[5]       PA05          1-15           H4.16        Potentiometer
 * LED0         PB00          1-3            H4.5
 * LED1         PB01          1-4            H4.7
 * LED2         PB02          1-7            H5.4
 * LED3         PB03          1-8            H5.5 
 * 5V           5.0V          PWR-3          H4.2
 * ground       GND           1-19           H4.4
 *
 * Tested with Atmel Studio 7 v7.0.1006 and Keil MDK-ARM v5.21a
 */

#include "samd21.h"

unsigned char* ARRAY_PORT_PINCFG0 = (unsigned char*)&REG_PORT_PINCFG0;
unsigned char* ARRAY_PORT_PMUX0 = (unsigned char*)&REG_PORT_PMUX0;

int main (void) {
    int result;

    REG_PORT_DIR1 |= 0x0000000F;        /* make PB03-PB00 output */

    REG_PM_APBCMASK |= 0x10000;         /* enable bus clock for ADC */
    REG_GCLK_CLKCTRL = 0x401E;          /* GCLK0 to ADC */
    REG_ADC_SAMPCTRL = 5;               /* sampling time 5 clocks */
    ARRAY_PORT_PINCFG0[3] |= 1;         /* Use PMUX for PA03 */
    ARRAY_PORT_PMUX0[1] = 0x10;         /* PA03 = VREFA */
    REG_ADC_REFCTRL = 3;                /* Use VREFA */
    REG_ADC_INPUTCTRL = 0x1805;         /* V- = GND; V+ = AIN5 */
    ARRAY_PORT_PINCFG0[5] |= 1;         /* Use PMUX for PA05 */
    ARRAY_PORT_PMUX0[2] = 0x10;         /* PA05 = AIN5 */
    REG_ADC_CTRLA = 2;                  /* enable ADC */

    while (1) {
        REG_ADC_SWTRIG = 2;             /* start a conversion */
        while(!(REG_ADC_INTFLAG & 1));  /* wait for conv complete */
        result = REG_ADC_RESULT;        /* read conversion result */
        REG_PORT_OUTCLR1 = 0x000F;      /* turn off all LEDs */
        REG_PORT_OUTSET1 = (result >> 8) & 0x000F;  /* turn on LEDs */
    }
}
