/* Read switches and use the data to set LEDs for EduPad 
 * with SAMD21 Xplained Pro
 *
 * Switche input pins are pull-down. When the switch is pressed, 
 * the signal goes high. LEDs are high active.
 *
 * Connections between SAMD21 Xplained Pro and EduPad:
 * Function     Pin name      Xplained pin   EduPad pin
 * S2           PA16          2-17           H4.6
 * S3           PA17          2-15           H4.8
 * S4           PA18          2-16           H4.10
 * S5           PA19          2-18           H4.12
 *
 * LED0         PB00          1-3            H4.5
 * LED1         PB01          1-4            H4.7
 * LED2         PB02          1-7            H5.4
 * LED3         PB03          1-8            H5.5 
 * 5V           5.0V          PWR-3          H4.2
 * ground       GND           1-19           H4.4
 *
 * Tested with Atmel Studio 7 v7.0.1006 and Keil MDK-ARM v5.21a
 */

#include "samd21.h"

void delayMs(int n);

int main (void) {
    unsigned char* ARRAY_PORT_PINCFG0 = (unsigned char*)&REG_PORT_PINCFG0;
    
    REG_PORT_DIRCLR0 = 0x000F0000;      /* make PA16-19 input for SW0 */
    ARRAY_PORT_PINCFG0[16] |= 6;        /* enable PA16 input buffer with pull */
    ARRAY_PORT_PINCFG0[17] |= 6;        /* enable PA17 input buffer with pull */
    ARRAY_PORT_PINCFG0[18] |= 6;        /* enable PA18 input buffer with pull */
    ARRAY_PORT_PINCFG0[19] |= 6;        /* enable PA19 input buffer with pull */
    REG_PORT_OUTCLR0 = 0x000F0000;      /* make PA16-19 pull-down */

    REG_PORT_DIR1 |= 0x0000000F;       /* make PB03-PB00 output */
    
    while(1) {
        REG_PORT_OUTCLR1 = 0x000F;  /* turn off all LEDs */
        REG_PORT_OUTSET1 = (REG_PORT_IN0 >> 16) & 0x000F;  /* turn on LEDs */
    }
}
