/* Toggle LEDs on EduPad with SAMD21 Xplained Pro
 * 
 * On EduPad board, PB03-PB00 are connected to the four LEDs.
 * Default clock 1 MHz is used.
 * Connections between SAMD21 Xplained Pro and EduPad:
 *
 * Function     Pin name      Xplained pin   EduPad pin
 * LED0         PB00          1-3            H4.5
 * LED1         PB01          1-4            H4.7
 * LED2         PB02          1-7            H5.4
 * LED3         PB03          1-8            H5.5 
 * ground       GND           1-19           H4.4
 *
 * Tested with Atmel Studio 7 v7.0.1006 and Keil MDK-ARM v5.21a
 */

#include "samd21.h"

void delayMs(int n);

int main (void) {
    REG_PORT_DIR1 |= 0x0000000F;       /* make PB03-PB00 output */

    /* toggle LED continuously at 1Hz */
    while(1) {
        REG_PORT_OUTCLR1 = 0x000F;  /* turn off all LEDs */
        REG_PORT_OUTSET1 = 0x0005;  /* turn on LED2, LED0 */
        delayMs(500);
        REG_PORT_OUTCLR1 = 0x000F;  /* turn off all LEDs */
        REG_PORT_OUTSET1 = 0x000A;  /* turn on LED3, LED1 */        
        delayMs(500);
    }
}

/* millisecond delay based on 1 MHz system clock */
void delayMs(int n) {
    int i;
    for (; n > 0; n--)
        for (i = 0; i < 199; i++)
            __asm("nop");
}
